@@ -2,6 +2,7 @@ package org.jsoup.helper;
 
 import org.jsoup.Connection;
 import org.jsoup.nodes.Document;
+import org.jsoup.parser.Parser;
 import org.jsoup.parser.TokenQueue;
 
 import java.io.*;
@@ -127,6 +128,19 @@ public class HttpConnection implements Connection {
         return this;
     }
 
+    public Connection cookies(Map<String, String> cookies) {
+        Validate.notNull(cookies, "Cookie map must not be null");
+        for (Map.Entry<String, String> entry : cookies.entrySet()) {
+            req.cookie(entry.getKey(), entry.getValue());
+        }
+        return this;
+    }
+
+    public Connection parser(Parser parser) {
+        req.parser(parser);
+        return this;
+    }
+
     public Document get() throws IOException {
         req.method(Method.GET);
         execute();
@@ -281,6 +295,7 @@ public class HttpConnection implements Connection {
         private Collection<Connection.KeyVal> data;
         private boolean ignoreHttpErrors = false;
         private boolean ignoreContentType = false;
+        private Parser parser;
 
       	private Request() {
             timeoutMilliseconds = 3000;
@@ -288,6 +303,7 @@ public class HttpConnection implements Connection {
             data = new ArrayList<Connection.KeyVal>();
             method = Connection.Method.GET;
             headers.put("Accept-Encoding", "gzip");
+            parser = Parser.htmlParser();
         }
 
         public int timeout() {
@@ -313,16 +329,18 @@ public class HttpConnection implements Connection {
             return ignoreHttpErrors;
         }
 
-        public void ignoreHttpErrors(boolean ignoreHttpErrors) {
+        public Connection.Request ignoreHttpErrors(boolean ignoreHttpErrors) {
             this.ignoreHttpErrors = ignoreHttpErrors;
+            return this;
         }
 
         public boolean ignoreContentType() {
             return ignoreContentType;
         }
 
-        public void ignoreContentType(boolean ignoreContentType) {
+        public Connection.Request ignoreContentType(boolean ignoreContentType) {
             this.ignoreContentType = ignoreContentType;
+            return this;
         }
 
         public Request data(Connection.KeyVal keyval) {
@@ -334,6 +352,15 @@ public class HttpConnection implements Connection {
         public Collection<Connection.KeyVal> data() {
             return data;
         }
+        
+        public Request parser(Parser parser) {
+            this.parser = parser;
+            return this;
+        }
+        
+        public Parser parser() {
+            return parser;
+        }
     }
 
     public static class Response extends Base<Connection.Response> implements Connection.Response {
@@ -359,7 +386,7 @@ public class HttpConnection implements Connection {
                     throw new IOException(String.format("Too many redirects occurred trying to load URL %s", previousResponse.url()));
             }
         }
-
+        
         static Response execute(Connection.Request req) throws IOException {
             return execute(req, null);
         }
@@ -389,6 +416,8 @@ public class HttpConnection implements Connection {
             Response res = new Response(previousResponse);
             res.setupFromConnection(conn, previousResponse);
             if (needsRedirect && req.followRedirects()) {
+                req.method(Method.GET); // always redirect with a get. any data param from original req are dropped.
+                req.data().clear();
                 req.url(new URL(req.url(), res.header("Location")));
                 for (Map.Entry<String, String> cookie : res.cookies.entrySet()) { // add response cookies to request (for e.g. login posts)
                     req.cookie(cookie.getKey(), cookie.getValue());
@@ -437,7 +466,7 @@ public class HttpConnection implements Connection {
             if (!req.ignoreContentType() && (contentType == null || !(contentType.startsWith("text/") || contentType.startsWith("application/xml") || contentType.startsWith("application/xhtml+xml"))))
                 throw new IOException(String.format("Unhandled content type \"%s\" on URL %s. Must be text/*, application/xml, or application/xhtml+xml",
                     contentType, url.toString()));
-            Document doc = DataUtil.parseByteData(byteData, charset, url.toExternalForm());
+            Document doc = DataUtil.parseByteData(byteData, charset, url.toExternalForm(), req.parser());
             byteData.rewind();
             charset = doc.outputSettings().charset().name(); // update charset from meta-equiv, possibly
             return doc;
