@@ -1168,6 +1168,7 @@ enum TokeniserState {
                     break;
                 case nullChar:
                     t.error(this);
+                    r.advance();
                     t.commentPending.data.append(replacementChar);
                     break;
                 case eof:
@@ -1363,7 +1364,9 @@ enum TokeniserState {
                 t.transition(Data);
                 return;
             }
-            if (r.matches('>')) {
+            if (r.matchesAny('\t', '\n', '\f', ' '))
+                r.advance(); // ignore whitespace
+            else if (r.matches('>')) {
                 t.emitDoctypePending();
                 t.advanceTransition(Data);
             } else if (r.matchConsumeIgnoreCase("PUBLIC")) {
