@@ -1,8 +1,14 @@
 package org.jsoup.helper;
 
 import static org.junit.Assert.assertEquals;
+
+import org.jsoup.nodes.Document;
+import org.jsoup.parser.Parser;
 import org.junit.Test;
 
+import java.nio.ByteBuffer;
+import java.nio.charset.Charset;
+
 public class DataUtilTest {
     @Test
     public void testCharset() {
@@ -18,4 +24,11 @@ public class DataUtilTest {
         assertEquals("UTF-8", DataUtil.getCharsetFromContentType("text/html;charset=\"utf-8\""));
         assertEquals("ISO-8859-1", DataUtil.getCharsetFromContentType("text/html; charset=\"ISO-8859-1\""));
     }
+    
+    @Test public void discardsSpuriousByteOrderMark() {
+        String html = "\uFEFF<html><head><title>One</title></head><body>Two</body></html>";
+        ByteBuffer buffer = Charset.forName("UTF-8").encode(html);
+        Document doc = DataUtil.parseByteData(buffer, "UTF-8", "http://foo.com/", Parser.htmlParser());
+        assertEquals("One", doc.head().text());
+    }
 }
